require 'icalendar/tzinfo'

class CandidatesController < ApplicationController
  def create
    @session = Session.find_by(ref_id: params[:session_ref_id])
    @conference = Conference.find_by(slug: params[:conference_slug])
    @user = User.find(session[:user_id])
    @candidate = Candidate.find_or_initialize_by(user: @user, session: @session).tap do |candidate_|
      candidate_.note = params[:note]
      candidate_.save!
    end

    if @candidate
      Rails.logger.debug("Saved candidate #{@candidate.inspect}")
      #@session = Session.find_by(ref_id: params[:session_ref_id])
      Turbo::StreamsChannel.broadcast_replace_to(
        @session.conference,
        target: helpers.dom_id(@session),
        partial: "sessions/session",
        locals: { session: @session }
      )
      flash.now[:success] = 'User assigned successfully.'
      respond_to do |format|
        format.turbo_stream { render turbo_stream: turbo_stream.replace(helpers.dom_id(@session), partial: "sessions/session", locals: { session: @session }) }
        format.html { redirect_to conference_session_path(@session.conference, @session), success: 'User assigned successfully.' }
      end
    else
      flash.now[:alert] = 'Failed to record candidate.'
      respond_to do |format|
        format.turbo_stream { render turbo_stream: turbo_stream.replace(helpers.dom_id(@session), partial: "sessions/session", locals: { session: @session }), status: :unprocessable_entity }
        format.html { render :show, status: :unprocessable_entity }
      end
    end
  end

  def destroy
    @candidate = Candidate.find(params[:id])
    @session = @candidate.session

    if @candidate&.destroy
      Rails.logger.debug("destroyed candidate entry")
      Turbo::StreamsChannel.broadcast_replace_later_to(
        @session.conference,
        target: helpers.dom_id(@session),
        partial: "sessions/session",
        locals: { session: @session }
      )
      respond_to do |format|
        format.turbo_stream { render turbo_stream: turbo_stream.replace(helpers.dom_id(@session), partial: "sessions/session", locals: { session: @session }) }
        format.html { redirect_to conference_session_path(@session.conference, @session), notice: 'Candidate removed successfully.' }
      end
    else
      respond_to do |format|
        format.turbo_stream { render turbo_stream: turbo_stream.replace(helpers.dom_id(@session), partial: "sessions/session", locals: { session: @session }), status: :unprocessable_entity }
        format.html { redirect_to conference_session_path(@session.conference, @session), alert: 'Failed to remove candidate.' }
      end
    end
  end
end
